justbases package
=================

Submodules
----------

.. toctree::

   justbases._config
   justbases._constants
   justbases._display
   justbases._division
   justbases._errors
   justbases._nats
   justbases._rationals
   justbases.version

Module contents
---------------

.. automodule:: justbases
    :members:
    :undoc-members:
    :show-inheritance:
